@@ -78,8 +78,8 @@ class DelegateSafe(ApeSafe):
         super().post_transaction(safe_tx)
 
         if self.is_ci and self.is_send:
-            with open(os.path.join(home_directory, "nonce.txt"), "w") as f:
-                f.write(str(safe_tx.safe_nonce))
+            with open(os.getenv('GITHUB_ENV'), 'a') as f:
+                f.write("NONCE={0}\n".format(str(safe_tx.safe_nonce)))
             exit(0)
 
     def preview(self, safe_tx: SafeTx, events=True, call_trace=False, reset=True):
@@ -125,8 +125,8 @@ class DelegateSafe(ApeSafe):
 
     def get_signer(self, signer: Optional[Union[LocalAccount, str]] = None) -> LocalAccount:
         if self.is_ci:
-            with open(os.path.join(home_directory, "safe.txt"), "w") as f:
-                f.write(str(self.frontend_url.format(self.address)))
+            with open(os.getenv('GITHUB_ENV'), 'a') as f:
+                f.write("SAFE_LINK={0}\n".format(str(self.frontend_url.format(self.address))))
 
             if self.is_send:
                 key = os.environ.get("PRIVATE_KEY")
