@@ -13,9 +13,11 @@ elif network.chain.id == 4:
     address = os.getenv("RIN_SAFE_ADDRESS")
 elif network.chain.id == 42161:
     address = os.getenv("ARB_SAFE_ADDRESS")
+elif network.chain.id == 100:
+    address = os.getenv("GNOSIS_SAFE_ADDRESS")
 else:
     address = os.getenv("ETH_SAFE_ADDRESS")
 
 safe = None
 if address:
-    safe = ApeSafe(address)
\ No newline at end of file
+    safe = ApeSafe(address)
